==> custom-scrollbar-0.0.8.jar: META-INF/resources/webjars/custom-scrollbar/README.md <==
[![Build status](https://travis-ci.org/DoubleTrade/custom-scrollbar.svg?branch=master)](https://travis-ci.org/DoubleTrade/custom-scrollbar)
[![Published on webcomponents.org](https://img.shields.io/badge/webcomponents.org-published-blue.svg)](https://www.webcomponents.org/element/doubletrade/range-datepicker)

## &lt;custom-scrollbar&gt;

`custom-scrollbar` provides a simple custom scrollbar for a container.

### Install

    bower install custom-scrollbar

[See live demo](https://doubletrade.github.io/custom-scrollbar/components/custom-scrollbar/demo/)
[See docs](https://doubletrade.github.io/custom-scrollbar/)


### Browser support

Chrome, Firefox, IE 11+/, Edge, Safari.


### Styling

`<custom-scrollbar>` provides the following custom properties and mixins for styling:

Custom property | Description | Default
----------------|-------------|----------
`--custom-scrollbar-height` | Height of the content | 200px
`--custom-scrollbar-bar` | Customize the bar | `{}`
`--custom-scrollbar-track` | Customize the track | `{}`

<!---
```
<custom-element-demo>
  <template>
    <script src="../webcomponentsjs/webcomponents-lite.js"></script>
    <link rel="import" href="custom-scrollbar.html">
    <style is="custom-style">
      div {
        height: 200px;
        width: 100%;
      }
    </style>
    <next-code-block></next-code-block>
  </template>
</custom-element-demo>
```
-->
```html
<div>
  <custom-scrollbar>
    Lorem ipsum dolor sit amet, prompta copiosae partiendo vix ex. Illud nullam mentitum sea in, elitr persius
    petentium ut mei. Numquam apeirian dissentiunt quo ut. Has in aliquam intellegat. Cum ad habemus
    rationibus, nostrum dissentiet ius no. Ius in augue laboramus, per cu elit illud interpretaris.
    Reque voluptatibus nam id, id has gloriatur reprehendunt. Quodsi vocent option eam te, id eum
    omnes probatus. Mel ex corpora pertinax suscipiantur, ceteros insolens eloquentiam ut cum,
    mei petentium consulatu id. Qui ex esse invidunt, et eum ferri facer timeam, cu pri impedit
    reformidans. Dicam bonorum vix ut, agam posidonium cotidieque ad nam, denique deleniti id duo.
    Cu inani assueverit nam, eam an inermis signiferumque. Vide maiorum qui ea, sea ex dictas civibus,
    tantas sadipscing eu vix. Te vivendum forensibus eam, has sonet utamur epicurei id, quot aeque
    quando est cu. Ferri ancillae deseruisse est cu, ut atqui corrumpit sea. Usu te tollit alterum
    pertinax, ei qui munere molestie voluptatibus, ea vel debet option senserit. Tollit commodo
    maluisset no pri, ex nihil graecis sit. Ne eum animal omittam periculis, et tation scribentur
    pro. Sit in antiopam vulputate consequuntur, albucius menandri corrumpit sit ei. Quo eros aeque
    ancillae ut, malorum pertinax eam id, an pri facilisis erroribus. Ad mea dolore vivendum, no
    idque prodesset pri. No postea tamquam delenit nec, elit altera graecis mei eu. An repudiare
    iracundia has, eum ea tation ceteros tibique. Electram vulputate in qui. Soluta iisque eos
    id, mel probo euismod dignissim at. An vitae intellegat neglegentur vis. Erat voluptua usu
    cu. Discere meliore postulant ne eam. Ne has vocent tamquam, vel rebum electram inciderint
    ne. Eu autem fuisset mel. Illum tamquam copiosae ad mei, te usu veniam periculis. Oporteat
    iracundia per te, et cum postulant tractatos omittantur. Praesent expetenda has ex, cu quas
    euripidis vix. Cu his percipit salutandi interesset. Partem blandit facilisis nam at. Sea ex
    luptatum singulis. Impetus alienum ea sea. Debitis mediocritatem ne his. Fuisset appareat imperdiet
    quo ne, vis quem causae forensibus ad. Alterum appareat has ea, eu eam viris deleniti appellantur,
    dicam iracundia persequeris no quo. Cum te labore graeco. Est ceteros expetendis incorrupte
    ad, est no dolorum vocibus. Ut qui velit elitr, ne vis posse complectitur. Id sea abhorreant
    signiferumque, vel eu omnis choro constituto. Mei ea dicat debet praesent, suas nominavi necessitatibus
    an sit. No alii laudem constituto has, unum fabellas prodesset duo at. Sea alii posse rationibus
    et, graeci omnium consetetur ne ius. Cibo lorem soluta eum eu, cu vix audire sanctus tacimates,
    posse utinam mediocrem et usu. Quo ut atqui recteque iudicabit. Error paulo voluptatibus nam
    eu, ei vim summo albucius persecuti. Eu vim aeque moderatius. Ei erant democritum nam, ad quando
    corpora copiosae vel. Lorem ipsum dolor sit amet, prompta copiosae partiendo vix ex. Illud
    nullam mentitum sea in, elitr persius petentium ut mei. Numquam apeirian dissentiunt quo ut.
    Has in aliquam intellegat. Cum ad habemus rationibus, nostrum dissentiet ius no. Ius in augue
    laboramus, per cu elit illud interpretaris. Reque voluptatibus nam id, id has gloriatur reprehendunt.
    Quodsi vocent option eam te, id eum omnes probatus. Mel ex corpora pertinax suscipiantur, ceteros
    insolens eloquentiam ut cum, mei petentium consulatu id. Qui ex esse invidunt, et eum ferri
    facer timeam, cu pri impedit reformidans. Dicam bonorum vix ut, agam posidonium cotidieque
    ad nam, denique deleniti id duo. Cu inani assueverit nam, eam an inermis signiferumque. Vide
    maiorum qui ea, sea ex dictas civibus, tantas sadipscing eu vix. Te vivendum forensibus eam,
    has sonet utamur epicurei id, quot aeque quando est cu. Ferri ancillae deseruisse est cu, ut
    atqui corrumpit sea. Usu te tollit alterum pertinax, ei qui munere molestie voluptatibus, ea
    vel debet option senserit. Tollit commodo maluisset no pri, ex nihil graecis sit. Ne eum animal
    omittam periculis, et tation scribentur pro. Sit in antiopam vulputate consequuntur, albucius
    menandri corrumpit sit ei. Quo eros aeque ancillae ut, malorum pertinax eam id, an pri facilisis
    erroribus. Ad mea dolore vivendum, no idque prodesset pri. No postea tamquam delenit nec, elit
    altera graecis mei eu. An repudiare iracundia has, eum ea tation ceteros tibique. Electram
    vulputate in qui. Soluta iisque eos id, mel probo euismod dignissim at. An vitae intellegat
    neglegentur vis. Erat voluptua usu cu. Discere meliore postulant ne eam. Ne has vocent tamquam,
    vel rebum electram inciderint ne. Eu autem fuisset mel. Illum tamquam copiosae ad mei, te usu
    veniam periculis. Oporteat iracundia per te, et cum postulant tractatos omittantur. Praesent
    expetenda has ex, cu quas euripidis vix. Cu his percipit salutandi interesset. Partem blandit
    facilisis nam at. Sea ex luptatum singulis. Impetus alienum ea sea. Debitis mediocritatem ne
    his. Fuisset appareat imperdiet quo ne, vis quem causae forensibus ad. Alterum appareat has
    ea, eu eam viris deleniti appellantur, dicam iracundia persequeris no quo. Cum te labore graeco.
    Est ceteros expetendis incorrupte ad, est no dolorum vocibus. Ut qui velit elitr, ne vis posse
    complectitur. Id sea abhorreant signiferumque, vel eu omnis choro constituto. Mei ea dicat
    debet praesent, suas nominavi necessitatibus an sit. No alii laudem constituto has, unum fabellas
    prodesset duo at. Sea alii posse rationibus et, graeci omnium consetetur ne ius. Cibo lorem
    soluta eum eu, cu vix audire sanctus tacimates, posse utinam mediocrem et usu. Quo ut atqui
    recteque iudicabit. Error paulo voluptatibus nam eu, ei vim summo albucius persecuti. Eu vim
    aeque moderatius. Ei erant democritum nam, ad quando corpora copiosae vel.
  </custom-scrollbar>
</div>
```

==> custom-scrollbar-0.0.10.jar: META-INF/resources/webjars/custom-scrollbar/README.md <==
[![Build status](https://travis-ci.org/DoubleTrade/custom-scrollbar.svg?branch=master)](https://travis-ci.org/DoubleTrade/custom-scrollbar)
[![Published on webcomponents.org](https://img.shields.io/badge/webcomponents.org-published-blue.svg)](https://www.webcomponents.org/element/doubletrade/custom-scrollbar)

## &lt;custom-scrollbar&gt;

`custom-scrollbar` provides a simple custom scrollbar for a container.

### Install

    bower install custom-scrollbar

[See live demo](https://doubletrade.github.io/custom-scrollbar/components/custom-scrollbar/demo/)
[See docs](https://doubletrade.github.io/custom-scrollbar/)


### Browser support

Chrome, Firefox, IE 11+/, Edge, Safari.


### Styling

`<custom-scrollbar>` provides the following custom properties and mixins for styling:

Custom property | Description | Default
----------------|-------------|----------
`--custom-scrollbar-height` | Height of the content | 200px
`--custom-scrollbar-bar` | Customize the bar | `{}`
`--custom-scrollbar-bar-track-hover` | Customize the bar when track is under cursor | `{}`
`--custom-scrollbar-bar-container-hover` | Customize the bar when container is under cursor | `{}`
`--custom-scrollbar-track` | Customize the track | `{}`
`--custom-scrollbar-track-hover` | Customize the track under cursor | `{}`
`--custom-scrollbar-track-container-hover` | Customize the track when container is under cursor | `{}`

<!---
```
<custom-element-demo>
  <template>
    <script src="../webcomponentsjs/webcomponents-lite.js"></script>
    <link rel="import" href="custom-scrollbar.html">
    <style is="custom-style">
      div {
        height: 200px;
        width: 100%;
      }
    </style>
    <next-code-block></next-code-block>
  </template>
</custom-element-demo>
```
-->
```html
<div>
  <custom-scrollbar>
    Lorem ipsum dolor sit amet, prompta copiosae partiendo vix ex. Illud nullam mentitum sea in, elitr persius
    petentium ut mei. Numquam apeirian dissentiunt quo ut. Has in aliquam intellegat. Cum ad habemus
    rationibus, nostrum dissentiet ius no. Ius in augue laboramus, per cu elit illud interpretaris.
    Reque voluptatibus nam id, id has gloriatur reprehendunt. Quodsi vocent option eam te, id eum
    omnes probatus. Mel ex corpora pertinax suscipiantur, ceteros insolens eloquentiam ut cum,
    mei petentium consulatu id. Qui ex esse invidunt, et eum ferri facer timeam, cu pri impedit
    reformidans. Dicam bonorum vix ut, agam posidonium cotidieque ad nam, denique deleniti id duo.
    Cu inani assueverit nam, eam an inermis signiferumque. Vide maiorum qui ea, sea ex dictas civibus,
    tantas sadipscing eu vix. Te vivendum forensibus eam, has sonet utamur epicurei id, quot aeque
    quando est cu. Ferri ancillae deseruisse est cu, ut atqui corrumpit sea. Usu te tollit alterum
    pertinax, ei qui munere molestie voluptatibus, ea vel debet option senserit. Tollit commodo
    maluisset no pri, ex nihil graecis sit. Ne eum animal omittam periculis, et tation scribentur
    pro. Sit in antiopam vulputate consequuntur, albucius menandri corrumpit sit ei. Quo eros aeque
    ancillae ut, malorum pertinax eam id, an pri facilisis erroribus. Ad mea dolore vivendum, no
    idque prodesset pri. No postea tamquam delenit nec, elit altera graecis mei eu. An repudiare
    iracundia has, eum ea tation ceteros tibique. Electram vulputate in qui. Soluta iisque eos
    id, mel probo euismod dignissim at. An vitae intellegat neglegentur vis. Erat voluptua usu
    cu. Discere meliore postulant ne eam. Ne has vocent tamquam, vel rebum electram inciderint
    ne. Eu autem fuisset mel. Illum tamquam copiosae ad mei, te usu veniam periculis. Oporteat
    iracundia per te, et cum postulant tractatos omittantur. Praesent expetenda has ex, cu quas
    euripidis vix. Cu his percipit salutandi interesset. Partem blandit facilisis nam at. Sea ex
    luptatum singulis. Impetus alienum ea sea. Debitis mediocritatem ne his. Fuisset appareat imperdiet
    quo ne, vis quem causae forensibus ad. Alterum appareat has ea, eu eam viris deleniti appellantur,
    dicam iracundia persequeris no quo. Cum te labore graeco. Est ceteros expetendis incorrupte
    ad, est no dolorum vocibus. Ut qui velit elitr, ne vis posse complectitur. Id sea abhorreant
    signiferumque, vel eu omnis choro constituto. Mei ea dicat debet praesent, suas nominavi necessitatibus
    an sit. No alii laudem constituto has, unum fabellas prodesset duo at. Sea alii posse rationibus
    et, graeci omnium consetetur ne ius. Cibo lorem soluta eum eu, cu vix audire sanctus tacimates,
    posse utinam mediocrem et usu. Quo ut atqui recteque iudicabit. Error paulo voluptatibus nam
    eu, ei vim summo albucius persecuti. Eu vim aeque moderatius. Ei erant democritum nam, ad quando
    corpora copiosae vel. Lorem ipsum dolor sit amet, prompta copiosae partiendo vix ex. Illud
    nullam mentitum sea in, elitr persius petentium ut mei. Numquam apeirian dissentiunt quo ut.
    Has in aliquam intellegat. Cum ad habemus rationibus, nostrum dissentiet ius no. Ius in augue
    laboramus, per cu elit illud interpretaris. Reque voluptatibus nam id, id has gloriatur reprehendunt.
    Quodsi vocent option eam te, id eum omnes probatus. Mel ex corpora pertinax suscipiantur, ceteros
    insolens eloquentiam ut cum, mei petentium consulatu id. Qui ex esse invidunt, et eum ferri
    facer timeam, cu pri impedit reformidans. Dicam bonorum vix ut, agam posidonium cotidieque
    ad nam, denique deleniti id duo. Cu inani assueverit nam, eam an inermis signiferumque. Vide
    maiorum qui ea, sea ex dictas civibus, tantas sadipscing eu vix. Te vivendum forensibus eam,
    has sonet utamur epicurei id, quot aeque quando est cu. Ferri ancillae deseruisse est cu, ut
    atqui corrumpit sea. Usu te tollit alterum pertinax, ei qui munere molestie voluptatibus, ea
    vel debet option senserit. Tollit commodo maluisset no pri, ex nihil graecis sit. Ne eum animal
    omittam periculis, et tation scribentur pro. Sit in antiopam vulputate consequuntur, albucius
    menandri corrumpit sit ei. Quo eros aeque ancillae ut, malorum pertinax eam id, an pri facilisis
    erroribus. Ad mea dolore vivendum, no idque prodesset pri. No postea tamquam delenit nec, elit
    altera graecis mei eu. An repudiare iracundia has, eum ea tation ceteros tibique. Electram
    vulputate in qui. Soluta iisque eos id, mel probo euismod dignissim at. An vitae intellegat
    neglegentur vis. Erat voluptua usu cu. Discere meliore postulant ne eam. Ne has vocent tamquam,
    vel rebum electram inciderint ne. Eu autem fuisset mel. Illum tamquam copiosae ad mei, te usu
    veniam periculis. Oporteat iracundia per te, et cum postulant tractatos omittantur. Praesent
    expetenda has ex, cu quas euripidis vix. Cu his percipit salutandi interesset. Partem blandit
    facilisis nam at. Sea ex luptatum singulis. Impetus alienum ea sea. Debitis mediocritatem ne
    his. Fuisset appareat imperdiet quo ne, vis quem causae forensibus ad. Alterum appareat has
    ea, eu eam viris deleniti appellantur, dicam iracundia persequeris no quo. Cum te labore graeco.
    Est ceteros expetendis incorrupte ad, est no dolorum vocibus. Ut qui velit elitr, ne vis posse
    complectitur. Id sea abhorreant signiferumque, vel eu omnis choro constituto. Mei ea dicat
    debet praesent, suas nominavi necessitatibus an sit. No alii laudem constituto has, unum fabellas
    prodesset duo at. Sea alii posse rationibus et, graeci omnium consetetur ne ius. Cibo lorem
    soluta eum eu, cu vix audire sanctus tacimates, posse utinam mediocrem et usu. Quo ut atqui
    recteque iudicabit. Error paulo voluptatibus nam eu, ei vim summo albucius persecuti. Eu vim
    aeque moderatius. Ei erant democritum nam, ad quando corpora copiosae vel.
  </custom-scrollbar>
</div>
```
